@@ -1,6 +1,6 @@
 /*
  * Ardesia-- a program for painting on the screen
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -215,6 +215,7 @@ annotate_acquire_input_grab ()
    * in mac this will do nothing 
    */
   gtk_widget_input_shape_combine_mask (data->annotation_window, NULL, 0, 0);
+  //drill_window_in_bar_area (data->annotation_window);
 #endif
 
 }
@@ -774,6 +775,9 @@ annotate_add_savepoint ()
   cairo_surface_t *source_surface = (cairo_surface_t *) NULL;
   cairo_t *cr = (cairo_t *) NULL;
 
+  /* The story about the future is deleted. */
+  annotate_redolist_free ();
+
   guint savepoint_index = g_slist_length (data->savepoint_list) + 1;
   
   savepoint->filename = g_strdup_printf ("%s%s%s_%d_vellum.png",
@@ -781,10 +785,6 @@ annotate_add_savepoint ()
 					 G_DIR_SEPARATOR_S,
 					 PACKAGE_NAME,
 					 savepoint_index);
-
-  /* The story about the future is deleted. */
-  annotate_redolist_free ();
-
   /* Add a new save-point. */
   data->savepoint_list = g_slist_prepend (data->savepoint_list, savepoint);
   data->current_save_index = 0;
@@ -845,13 +845,14 @@ initialize_annotation_cairo_context(AnnotateData *data)
 
       if (data->savepoint_list == NULL)
 	{
-	  annotate_reset_cairo ();
-	  clear_cairo_context (data->annotation_cairo_context);
+          /* Clear the screen and create the first empty savepoint. */
+	  annotate_clear_screen ();
 	}
 #ifndef _WIN32
       gtk_window_set_opacity(GTK_WINDOW(data->annotation_window), 1.0);
 #endif 	
       annotate_acquire_grab ();
+      
     }
 }
 
@@ -860,6 +861,12 @@ initialize_annotation_cairo_context(AnnotateData *data)
 void
 annotate_restore_surface ()
 {
+
+  if (data->debug)
+    {
+      g_printerr ("Restore surface\n");
+    }
+
   if (data->annotation_cairo_context)
     {
       guint i = data->current_save_index;
@@ -878,7 +885,6 @@ annotate_restore_surface ()
 	  return;
 	}
 
-
       cairo_new_path (data->annotation_cairo_context);
       cairo_set_operator (data->annotation_cairo_context, CAIRO_OPERATOR_SOURCE);
 
@@ -1366,7 +1372,7 @@ annotate_release_input_grab ()
   gdk_window_set_cursor (gtk_widget_get_window (data->annotation_window), (GdkCursor *) NULL);
 #ifndef _WIN32
   /*
-   * @TODO implement correctly gdk_window_input_shape_combine_mask
+   * @TODO implement correctly gtk_widget_input_shape_combine_mask
    * in the quartz gdkwindow or use an equivalent native function;
    * the current implementation in macosx this does not do nothing.
    */
@@ -1374,13 +1380,13 @@ annotate_release_input_grab ()
    * This allows the mouse event to be passed below the transparent annotation;
    * at the moment this call works only on Linux
    */
-  gdk_window_input_shape_combine_mask (gtk_widget_get_window (data->annotation_window), data->shape, 0, 0);
+  gtk_widget_input_shape_combine_mask (data->annotation_window, data->shape, 0, 0);
 #else
   /*
-   * @TODO WIN32 implement correctly gdk_window_input_shape_combine_mask
+   * @TODO WIN32 implement correctly gtk_widget_input_shape_combine_mask
    * in the win32 gdkwindow or use an equivalent native function.
-   * Now in the gtk implementation the gdk_window_input_shape_combine_mask
-   * call the gdk_window_shape_combine_mask that is not the desired behaviour.
+   * Now in the gtk implementation the gtk_widget_input_shape_combine_mask
+   * call the gtk_widget_shape_combine_mask that is not the desired behaviour.
    *
    */
   annotate_release_pointer_grab ();
@@ -1452,23 +1458,18 @@ void annotate_fill ()
 void
 annotate_undo ()
 {
+  if (data->debug)
+    {
+      g_printerr ("Undo\n");
+    }
+
   if (data->savepoint_list)
     {
-      if (data->debug)
+      if (data->current_save_index != g_slist_length (data->savepoint_list)-1)
 	{
-	  g_printerr ("Undo\n");
-	}
-      if (data->current_save_index != g_slist_length (data->savepoint_list))
-	{
-
 	  data->current_save_index = data->current_save_index + 1;
-	  annotate_restore_surface ();
-	}
-      else
-        {
-	  data->current_save_index = g_slist_length (data->savepoint_list);
           annotate_restore_surface ();
-        }
+	}
     }
 }
 
@@ -1476,16 +1477,15 @@ annotate_undo ()
 /* Redo to the last save point. */
 void annotate_redo ()
 {
+  if (data->debug)
+   {
+      g_printerr ("Redo\n");
+   }
+
   if (data->savepoint_list)
     {
       if (data->current_save_index != 0)
 	{
-
-	  if (data->debug)
-	    {
-	      g_printerr ("Redo\n");
-	    }
-
 	  data->current_save_index = data->current_save_index - 1;
 	  annotate_restore_surface ();
 	}
@@ -1493,7 +1493,7 @@ void annotate_redo ()
 }
 
 
-/* Clear the annotations windows. */
+/* Clear the annotations windows and make an empty savepoint. */
 void annotate_clear_screen ()
 {
   if (data->debug)
@@ -1503,6 +1503,8 @@ void annotate_clear_screen ()
 
   annotate_reset_cairo ();
   clear_cairo_context (data->annotation_cairo_context);
+  gtk_widget_queue_draw_area (data->annotation_window, 0, 0, gdk_screen_width (), gdk_screen_height ());
+  /* Add the empty savepoint. */
   annotate_add_savepoint ();
 }
 
