@@ -4,7 +4,7 @@
  * This program has been written such as a freedom sonet
  * We believe in the freedom and in the freedom of education
  *
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -40,8 +40,6 @@
 #include <pdf_saver.h>
 
 
-#ifndef _WIN32
-
 /* Timer used to up-rise the window. */
 static gint timer = -1;
 
@@ -62,16 +60,13 @@ bar_to_top (gpointer data)
   return TRUE;
 }
 
-#endif
-
-
 /* Called when close the program. */
 static gboolean
 quit (BarData *bar_data)
 {
   annotate_quit ();
   quit_pdf_saver ();
-  quit_recorder ();
+  stop_recorder ();
 
   /* Dis-allocate all the BarData structure. */
   if (bar_data)
@@ -190,11 +185,10 @@ release_lock(BarData *bar_data)
       bar_data->grab = FALSE;
       annotate_release_grab ();
 
-#ifndef _WIN32
       /* Try to up-rise the window. */
       timer = g_timeout_add (BAR_TO_TOP_TIMEOUT, bar_to_top, get_background_window ());
-#else // WIN32
-
+	  
+#ifdef _WIN32 // WIN32
       if (gtk_window_get_opacity (GTK_WINDOW (get_background_window ()))!=0)
 	{
 	  /* 
@@ -220,8 +214,7 @@ lock (BarData *bar_data)
     {
       // Unlock
       bar_data->grab = TRUE;
-#ifndef _WIN32
-
+	  
       /* delete the old timer */
       if (timer!=-1)
         { 
@@ -229,7 +222,7 @@ lock (BarData *bar_data)
 	  timer = -1;
         }
 
-#else // WIN32
+#ifdef _WIN32 // WIN32
 
       /* 
        * @HACK Deny the mouse input to go below the window putting the opacity greater than 0
@@ -369,6 +362,7 @@ on_bar_info                      (GtkToolButton   *toolbutton,
   gboolean grab_value = bar_data->grab;
   bar_data->grab = FALSE;
 
+  gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
   /* Start the info dialog. */
   start_info_dialog (toolbutton, GTK_WINDOW (get_bar_window ()));
 
@@ -573,6 +567,7 @@ on_bar_screenshot_activate	(GtkToolButton   *toolbutton,
   BarData *bar_data = (BarData *) func_data;
   gboolean grab_value = bar_data->grab;
   bar_data->grab = FALSE;
+  gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
   start_save_image_dialog (toolbutton, GTK_WINDOW (get_bar_window ()));
   bar_data->grab = grab_value;
   start_tool (bar_data);
@@ -610,6 +605,7 @@ on_bar_recorder_activate        (GtkToolButton   *toolbutton,
     {
       /* Visualize a dialog that informs the user about the missing recorder tool. */
       GObject *recorder_obj = gtk_builder_get_object (bar_gtk_builder, "media-recorder-unavailable");
+      gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
       visualize_missing_recorder_program_dialog (GTK_WINDOW (get_bar_window ()));
       /* Put an icon that remember that the tool is not available. */
       gtk_tool_button_set_label_widget (toolbutton, GTK_WIDGET (recorder_obj));
@@ -618,16 +614,24 @@ on_bar_recorder_activate        (GtkToolButton   *toolbutton,
       return;
     }
 	
-  if (is_recording ())
+  if (is_started ())
     {
-      quit_recorder ();
-      /* Set the stop tool-tip. */ 
-      gtk_tool_item_set_tooltip_text ( (GtkToolItem *) toolbutton, gettext ("Record"));
-      /* Put the record icon. */
-      gtk_tool_button_set_stock_id (toolbutton, "gtk-media-record");
+      if (is_paused ())
+        {
+          resume_recorder ();
+        }
+      else
+        {
+          pause_recorder ();
+          /* Set the stop tool-tip. */ 
+          gtk_tool_item_set_tooltip_text ( (GtkToolItem *) toolbutton, gettext ("Record"));
+          /* Put the record icon. */
+          gtk_tool_button_set_stock_id (toolbutton, "gtk-media-record");
+        }
     }
   else
     { 
+      gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
       /* The recording is not active. */ 
       gboolean status = start_save_video_dialog (toolbutton, GTK_WINDOW (get_bar_window ()));
       if (status)
@@ -651,6 +655,7 @@ on_bar_preferences_activate	(GtkToolButton   *toolbutton,
   BarData *bar_data = (BarData *) func_data;
   gboolean grab_value = bar_data->grab;
   bar_data->grab = FALSE;
+  gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
   start_preference_dialog (GTK_WINDOW (get_bar_window ()));
   bar_data->grab = grab_value;
   start_tool (bar_data);
@@ -699,7 +704,7 @@ on_bar_color_activate	        (GtkToggleToolButton   *toolbutton,
     }
 
   bar_data->grab = FALSE;
-
+  gdk_window_set_cursor (get_annotation_window ()->window, (GdkCursor *) NULL);
   new_color = start_color_selector_dialog (GTK_TOOL_BUTTON (toolbutton),
 					   GTK_WINDOW (get_bar_window ()),
 					   bar_data->color);
