@@ -1,6 +1,6 @@
 /* 
  * Ardesia-- a program for painting on the screen 
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -37,7 +37,8 @@ add_background_image_reference (gchar *project_tmp_dir,
   /* It is an image */
   gchar *background_path = "";
   background_path = g_build_filename (project_tmp_dir, href, (gchar *) 0);
-  set_background_image (background_path);
+  set_background_type (2);
+  update_background_image (background_path);
 }
 
 
@@ -95,7 +96,17 @@ add_background_color_reference (xmlXPathContextPtr context,
 				 ad
 				 );
 
-  set_background_color (rgba);
+  if (g_strcmp0 (rgba, "00000000") != 0)
+    {
+       set_background_type (1);
+       update_background_color (rgba);
+    }
+  else
+    { 
+       update_background_color (rgba);
+       set_background_color ("000000FF");
+    }
+
 
   g_free( (gchar *) alpha);
   g_free( (gchar *) xpath);
