@@ -4,7 +4,7 @@
  * This program has been written such as a freedom sonet
  * We believe in the freedom and in the freedom of education
  *
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -119,45 +119,48 @@ add_background (gchar *img_dir_path,
 {
   gint width  = gdk_screen_width ();
   gint height = gdk_screen_height ();
+  gchar *image_destination_path = (gchar *) NULL;
 
+  image_destination_path = g_build_filename (img_dir_path, "ardesia_0_vellum.png", (gchar *) 0);
 
-  gchar *image_destination_path = g_build_filename (img_dir_path, "ardesia_0_vellum.png", (gchar *) 0);
-
-  g_remove(image_destination_path);
-
-  if (background_image)
+  /* Background image valid and set to image type */
+  if ((background_image) && (get_background_type ()==2))
     {
-      // copy the file in ardesia_0_vellum.png under image_path
-      GFile *image_destination = g_file_new_for_path(image_destination_path);
-      GFile *image_source = g_file_new_for_path(background_image);
+      /* if the background is oupdated */
+      if (g_strcmp0 (background_image, image_destination_path) != 0)
+        {
+          /* copy the file in ardesia_0_vellum.png under image_path overriding it */
+          GFile *image_destination = g_file_new_for_path(image_destination_path);
+          GFile *image_source = g_file_new_for_path(background_image);
 
-      g_file_copy (image_source,
-                   image_destination,
-		   G_FILE_COPY_OVERWRITE,
-		   NULL,
-		   NULL,
-		   NULL,
-		   NULL);
+          g_file_copy (image_source,
+                       image_destination,
+	               G_FILE_COPY_OVERWRITE,
+		       NULL,
+	               NULL,
+	               NULL,
+	               NULL);
 
+          g_object_unref (image_source);
+          g_object_unref (image_destination);
+        }
       add_savepoint (0);
-
-      g_object_unref (image_source);
-      g_object_unref (image_destination);
     }
   else
     {
-
       gchar *color = get_background_color();
-      guint r, g, b, a;
+      /* Initialize the rgba components to transparent */
+      guint r = 0;
+      guint g = 0;
+      guint b = 0;
+      guint a = 0;
 
-      if (color!=NULL)
+      /* If the background type is colour then parse it */
+      if ((color!=NULL) && (get_background_type ()!=0))
 	{
 	  sscanf (color, "%02X%02X%02X%02X", &r, &g, &b, &a);
         }
-      else
-	{
-          r = 0; g=0; b=0; a=0;
-	}
+  
       gchar *rgb  =  g_strdup_printf ("rgb(%d,%d,%d)", r, g, b);
 
       open_svg ();
@@ -362,7 +365,7 @@ export_iwb (gchar *iwb_location)
 
   gchar *background_image = get_background_image();
 
-  gchar *first_savepoint_file = g_strdup_printf ("%s%s%s_1_vellum.png", img_dir_path, G_DIR_SEPARATOR_S, PACKAGE_NAME);
+  gchar *first_savepoint_file = g_strdup_printf ("%s%s%s_2_vellum.png", img_dir_path, G_DIR_SEPARATOR_S, PACKAGE_NAME);
 
   /* if exist the file I continue to save */
   if ((file_exists(first_savepoint_file)) || (background_image))
