@@ -4,7 +4,7 @@
  * This program has been written such as a freedom sonet
  * We believe in the freedom and in the freedom of education
  *
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,11 +26,37 @@
 #  include <config.h>
 #endif
 
+#include <utils.h>
 #include <preference_dialog.h>
+#include <background_window.h>
 #include <annotation_window.h>
 #include <keyboard.h>
 
 
+/* Show the permission denied to access to file dialog. */
+void
+show_permission_denied_dialog (GtkWindow *parent_window)
+{
+  GtkWidget *permission_denied_dialog = (GtkWidget *) NULL;
+
+  permission_denied_dialog = gtk_message_dialog_new (parent_window,
+					             GTK_DIALOG_MODAL,
+                                                     GTK_MESSAGE_ERROR,
+                                                     GTK_BUTTONS_OK,
+                                                     gettext ("Fail to open the file: Permission denied"));
+
+  gtk_window_set_modal (GTK_WINDOW (permission_denied_dialog), TRUE);
+
+  gtk_dialog_run (GTK_DIALOG (permission_denied_dialog));
+
+  if (permission_denied_dialog != NULL)
+    {
+      gtk_widget_destroy (permission_denied_dialog);
+      permission_denied_dialog = NULL;
+    }
+}
+
+
 /*
  * Start the dialog that ask to the user
  * the background setting.
@@ -52,9 +78,6 @@ start_preference_dialog (GtkWindow *parent)
 
   preference_data = g_malloc ((gsize) sizeof (PreferenceData));
 
-  /* 0 no background, 1 background colour, 2 png background. */
-  preference_data->background = 0;
-
   /* Initialize the main window. */
   preference_data->preference_dialog_gtk_builder = gtk_builder_new ();
 
@@ -99,22 +122,39 @@ start_preference_dialog (GtkWindow *parent)
 
   /* Connect all signals by reflection. */
   gtk_builder_connect_signals (preference_data->preference_dialog_gtk_builder, (gpointer) preference_data);
-   
-  if (preference_data->background == 1)
+
+  gint background_type = get_background_type();
+
+  if (background_type == 1)
     {
-      GObject *color_obj = gtk_builder_get_object (preference_data->preference_dialog_gtk_builder, "colour");
-      GtkToggleButton *colorToolButton = GTK_TOGGLE_BUTTON (color_obj);
-      gtk_toggle_button_set_active (colorToolButton, TRUE);
+      GObject *color_obj = gtk_builder_get_object (preference_data->preference_dialog_gtk_builder, "color");
+      GtkToggleButton *color_tool_button = GTK_TOGGLE_BUTTON (color_obj);
+      gtk_toggle_button_set_active (color_tool_button, TRUE);
     }
-  else if (preference_data->background == 2)
+  else if (background_type == 2)
     {
       GObject *file_obj = gtk_builder_get_object (preference_data->preference_dialog_gtk_builder, "file");
       GtkToggleButton *image_tool_button = GTK_TOGGLE_BUTTON (file_obj);
       gtk_toggle_button_set_active (image_tool_button, TRUE);
     }
 
+  gchar *rgba = get_background_color ();
+  if (rgba)
+    {
+      GdkColor *gdkcolor = rgba_to_gdkcolor (rgba);
+      guint16 alpha = strtol(&rgba[6], NULL, 16) * 257;
+      gtk_color_button_set_alpha (GTK_COLOR_BUTTON (color_button), alpha);
+      gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), gdkcolor);
+    }
+
+  gchar *filename = get_background_image ();
+  if (filename)
+    {
+      gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (chooser), filename);
+    }
+
   gtk_dialog_run (GTK_DIALOG (preference_dialog));
-  
+
   if (preference_dialog)
     {
       gtk_widget_destroy (preference_dialog);
