@@ -4,7 +4,7 @@
  * This program has been written such as a freedom sonet
  * We believe in the freedom and in the freedom of education
  *
- * Copyright (C) 2009 Pilolli Pietro <pilolli@fbk.eu>
+ * Copyright (C) 2009 Pilolli Pietro <pilolli.pietro@gmail.com>
  *
  * Ardesia is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -352,8 +352,8 @@ grab_screenshot ()
 gboolean inside_bar_window (gdouble xp, gdouble yp)
 {
   gint x = 0;
-  gint y =0;
-  gint width =0 ;
+  gint y = 0;
+  gint width = 0;
   gint height = 0;
   gdouble xd = 0;
   gdouble yd = 0;
@@ -380,7 +380,7 @@ gboolean inside_bar_window (gdouble xp, gdouble yp)
 
 /* Drill the gdk window in the area where the ardesia bar is located. */
 void
-drill_window_in_bar_area (GdkWindow *window)
+drill_window_in_bar_area (GtkWidget *widget)
 {
   /* Instantiate a transparent pixmap with a black hole upon the bar area to be used as mask. */
   GdkBitmap *shape = gdk_pixmap_new (NULL,  gdk_screen_width (), gdk_screen_height (), 1);
@@ -400,7 +400,7 @@ drill_window_in_bar_area (GdkWindow *window)
   cairo_rectangle (shape_cr, (double) x, (double) y, (double) width, (double) height);
   cairo_fill (shape_cr);	
 
-  gdk_window_input_shape_combine_mask (window,
+  gtk_widget_input_shape_combine_mask (widget,
 				       shape,
 				       0,
 				       0);
